==> Paws-0.35.tar.gz: Paws-0.35/lib/Paws/Firehose/SourceDescription.pm <==
package Paws::Firehose::SourceDescription;
  use Moose;
  has KinesisStreamSourceDescription => (is => 'ro', isa => 'Paws::Firehose::KinesisStreamSourceDescription');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Firehose::SourceDescription

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::Firehose::SourceDescription object:

  $service_obj->Method(Att1 => { KinesisStreamSourceDescription => $value, ..., KinesisStreamSourceDescription => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::Firehose::SourceDescription object:

  $result = $service_obj->Method(...);
  $result->Att1->KinesisStreamSourceDescription

=head1 DESCRIPTION

Details about a Kinesis stream used as the source for a Kinesis
Firehose delivery stream.

=head1 ATTRIBUTES


=head2 KinesisStreamSourceDescription => L<Paws::Firehose::KinesisStreamSourceDescription>

  The KinesisStreamSourceDescription value for the source Kinesis stream.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::Firehose>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.39.tar.gz: Paws-0.39/lib/Paws/Firehose/SourceDescription.pm <==
package Paws::Firehose::SourceDescription;
  use Moose;
  has KinesisStreamSourceDescription => (is => 'ro', isa => 'Paws::Firehose::KinesisStreamSourceDescription');
1;

### main pod documentation begin ###

=head1 NAME

Paws::Firehose::SourceDescription

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::Firehose::SourceDescription object:

  $service_obj->Method(Att1 => { KinesisStreamSourceDescription => $value, ..., KinesisStreamSourceDescription => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::Firehose::SourceDescription object:

  $result = $service_obj->Method(...);
  $result->Att1->KinesisStreamSourceDescription

=head1 DESCRIPTION

Details about a Kinesis data stream used as the source for a Kinesis
Data Firehose delivery stream.

=head1 ATTRIBUTES


=head2 KinesisStreamSourceDescription => L<Paws::Firehose::KinesisStreamSourceDescription>

  The KinesisStreamSourceDescription value for the source Kinesis data
stream.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::Firehose>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
